==> mongo-cursor-pagination-3.0.1.tgz: package/src/findWithReq.js <==
var find = require('./find');
var _ = require('underscore');

/**
 * A wrapper around `find()` that make it easy to implement a basic HTTP API using Express. So your
 * user can call "/list?limit=1&fields=_id,name" and the querystring parameters will be passed
 * to this method on the Express request object.
 *
 * @params {ExpressRequest} req An express request object with the following on the querystring:
 *    -limit: If a numeric string, passed to `find()` as the limit. If limit also passed in params
 *      then this value cannot exceed it.
 *    -next: If a non-empty string, passed to `find()` as the next cursor.
 *    -previous: If a non-empty string, passed to `find()` as the previous cursor.
 *    -fields: If a non-empty string, used to limit fields that are returned. Multiple fields
 *      can be specified as a comma-delimited list. If field name used is not in params.fields,
 *      it will be ignored.
 * @params {MongoCollection} collection A collection object returned from the MongoDB library's
 *    `db.collection(<collectionName>)` method.
 * @param {Object} params See documentation for `find()`.
 * @param {Function} done Node errback style function.
 */
module.exports = function(req, collection, params, done) {
  params = params || {};

  if (!_.isEmpty(req.query.limit)) {
    var limit = parseInt(req.query.limit);
    if (!isNaN(limit) && (!params.limit || params.limit > limit)) {
      params.limit = limit;
    }
  }

  if (!_.isEmpty(req.query.next)) {
    params.next = req.query.next;
  }

  if (!_.isEmpty(req.query.previous)) {
    params.previous = req.query.previous;
  }

  if (!_.isEmpty(req.query.fields)) {
    if (params.fields) {
      params.fields = _.pick(params.fields, req.query.fields.split(','));
    } else {
      params.fields = req.query.fields.split(',').reduce((accum, field) => {
        accum[field] = 1;
        return accum;
      }, {});
    }
  }

  find(collection, params, done);
};

==> mongo-cursor-pagination-3.1.0.tgz: package/src/findWithReq.js <==
var find = require('./find');
var dotFieldIntersect = require('./utils/dotFieldIntersect');
var _ = require('underscore');

/**
 * A wrapper around `find()` that make it easy to implement a basic HTTP API using Express. So your
 * user can call "/list?limit=1&fields=_id,name" and the querystring parameters will be passed
 * to this method on the Express request object.
 *
 * @params {ExpressRequest} req An express request object with the following on the querystring:
 *    -limit: If a numeric string, passed to `find()` as the limit. If limit also passed in params
 *      then this value cannot exceed it.
 *    -next: If a non-empty string, passed to `find()` as the next cursor.
 *    -previous: If a non-empty string, passed to `find()` as the previous cursor.
 *    -fields: If a non-empty string, used to limit fields that are returned. Multiple fields
 *      can be specified as a comma-delimited list. If field name used is not in params.fields,
 *      it will be ignored.
 * @params {MongoCollection} collection A collection object returned from the MongoDB library's
 *    `db.collection(<collectionName>)` method.
 * @param {Object} params See documentation for `find()`.
 * @param {Function} done Node errback style function.
 */
module.exports = function(req, collection, params, done) {
  params = params || {};

  if (!_.isEmpty(req.query.limit)) {
    var limit = parseInt(req.query.limit);
    if (!isNaN(limit) && (!params.limit || params.limit > limit)) {
      params.limit = limit;
    }
  }

  if (!_.isEmpty(req.query.next)) {
    params.next = req.query.next;
  }

  if (!_.isEmpty(req.query.previous)) {
    params.previous = req.query.previous;
  }

  if (!_.isEmpty(req.query.fields)) {
    var fields = req.query.fields.split(',');
    if (params.fields) {
      // Don't trust fields passed in the querystring, so whitelist them against the
      // fields defined in parameters.
      fields = dotFieldIntersect(Object.keys(params.fields), fields);
    }
    params.fields = fields.reduce((accum, field) => {
      accum[field] = 1;
      return accum;
    }, {});
  }

  find(collection, params, done);
};
